
Ext.define('DSS.addon.Lizard', {

    extend: 'DSS.addon.Framework',

    config: {
        appName: _('LED Wizard'),
        appId: 'led-wizard',
        appVersion: '1.0.0',
        appIcon: 'default_icon.png'
    },

    getHelp: function() {
        return Ext.create('Ext.Component', {
            loader: {
                url: 'locale/' + dss.staticDataModel.activeLanguage + '/help.html',
                autoLoad: true,
                disableCaching: false
            }
        });
    },
    illuminantTypeControl:null,
    getContent: function() {
        var me=this;
        illuminantTypeControl= Ext.create('DSS.addon.IlluminantType' ,{});
        illuminantTestControl= Ext.create('DSS.addon.IlluminantTest' ,{});
        
        var oConfig={
                defaultSortCol:'name',
                storeConfig: {
                    storeId : 'lizardStore',
                    fields : [ {name:'id'}, 
                               {name:'device', sortType:'asUCText'}, 
                               {name:'type', sortType:'asUCText'} ]  
                },
                columns: [ {
                    header : _('Device name'),
                    dataIndex : 'dsid',
                    xtype: 'devicenamecolumn', 
                    flex : 5,
                }, {
                    header: _('Dsid'),
                    dataIndex: 'dsid',
                    xtype: 'devicedsidcolumn', 
                    width: 200
                }, {
                    header: _('led type'),
                    dataIndex: 'catalogeID',
                    xtype: 'textcolumn', 
                    customColumnRenderer: function (val, metadata, record, rowIdx, colIdx, store, view) {
                        var oRecord=Ext.data.StoreManager.lookup('illuminateTypeStore').findRecord('id',val,0,false,false,true);
                        return oRecord.get('type') + '(' + oRecord.get('vendor') + ')';
                    },
                    width: 160
                }, {
                    header: _('modified at'),
                    dataIndex: 'ts',
                    xtype: 'timestampcolumn', 
                    width: 160
                }],     
                buttonText: {
                    newButton: _('New device'),
                    editButton: _('Edit device'),
                   
                    deleteButton: _('Reset device'),
                },
                customButtons:[{
                    text:_('Make a Demo'),
                    iconCls:'',
                    handler:function(grid,entry){
                        dss.raiseEvent('led-wizard',{actions:'startDemoModus',dsid:entry.get('dsid')});
                    }
                },
                {
                    text:_('Stop Demo'),
                    iconCls:'',
                    handler:function(grid,entry){
                        dss.raiseEvent('led-wizard',{actions:'stopDemoModus'})
                    }
                }],
                editorConfig:{
                    title : _('Edit Deviceconfig'),
                    staticControls : [ {
                        type: 'hidden',
                        label: 'id',
                        id: 'id'
                    }],
                    tabControls : [{
                        tabLabel : _('Deviceselection'),
                        tabDescription : _('Choose the device, on which the dimmingcurve should be optimized'),
                        content : [{
                               type : 'deviceSelection',
                               id : 'device', 
                               filterFunc: function (device) {return (([200,6344,1234].indexOf(device.productID)!=-1)&&(device.outputMode!=0));}, // sdm fehlt
                               specialDeviceRenderer:   function(val, metadata, record, colIdx, store, view) {
                                   var sReturn='<table style="height:16px;"><tr>';
                                   sReturn+='<td><img src="' + record.get('icon') + '" style="margin-right: 5px;"></td>';
                                   sReturn+='<td width="100%">' + record.get('name') + '</td><td>';
                                   sReturn+=dss.staticDataModel.getProductNameForDevice(dss.staticDataModel.getDevice(record.get('dSID')))+'</td>';    
                                   return sReturn +'</tr></table>';      
                               },
                               flex : true
                          }]
                    }, {
                        tabLabel : _('illuminant'),
                        tabDescription : _('Choose the type of the illuminant'),
                        content : [{
                            type : 'custom',
                            id : 'type',
                            control: illuminantTypeControl,
                            flex : true
                        }]
                    }, {
                        tabLabel : _('Test'),
                        tabDescription : _('Send the dimmingcurve to the device and test the result'),
                        content : [{
                            type : 'custom',
                            id : 'aaa',
                            control: illuminantTestControl,
                            flex : true
                        }]
                    }]
                },
                listeners: {
                    'loadDataStore':function (grid){
                        me.loadParameter(grid);
                    },
                    'saveEntry':function (grid,values){   
                        dss.raiseEvent('led-wizard',{actions:'setValuesFromCatalog',dsid:values.device,legal:false,catid:values.type});
                        me.waitAndReload(grid);
                    },
                    'deleteEntry':function (grid,entry){
                        dss.raiseEvent('led-wizard',{actions:'setValuesFromCatalog',dsid:entry.get('dsid'),legal:false,catid:0});
                        me.waitAndReload(grid);
                    },
                }
        };
                      
        return Ext.create('DSS.gridPanel', oConfig);
    },
    waitAndReload : function(grid) { 
        var oWait=Ext.Msg.wait(_('Please wait for transmitting the data'));     
        var me = this;
        var iSubscriptID = Math.floor(Math.random() * 100000000000);
        dss.ajaxSyncRequest('/json/event/subscribe', {
            subscriptionID : iSubscriptID,
            name : 'led-wizard.answer'
        });
        dss.ajaxAssyncRequestWithoutAnswer('/json/event/get', {
            subscriptionID : iSubscriptID,
            timeout : 60 * 1000
        }, function(DochAnswer) {
            var result=Ext.JSON.decode(DochAnswer);
            me.loadParameter(grid);
            dss.ajaxAssyncRequestWithoutAnswer('/json/event/unsubscribe', {
                subscriptionID : iSubscriptID,
                name : 'led-wizard.answer'
            });
            oWait.close();
            if (result.result.events[0]!=null) {
                if (result.result.events[0].properties.result=='false') {
                    Ext.Msg.alert(_('Not completed'),_('The transmission of the data was not succesfully completed'));
                } else {
                    Ext.Msg.alert('',_('The transmission of the data was succesfully completed'));
                }

            }
        });
        
    },
    loadParameter : function(grid) {
        var sString = dss.ajaxSyncRequest('/json/property/query', {
            'query' : '/scripts/led-wizard/devices/*(*)'
        });
        var result = Ext.JSON.decode(sString);
        var oResultObject=dss.parsePropertyQueryAnswer(result,[{name:'dsid',type:'simple'},
                                                               {name:'catalogeID',type:'simple'},
                                                               {name: 'ts',type:'simple'}]);  
        if (oResultObject!=null) {
            grid.loadParameter(oResultObject);
        }
    }
});

Ext.onReady(function() {
    dss.buildUpLang(['locale/{languageSuffix}/led-wizard.po']);
    
    if (Ext.data.StoreManager.lookup('illuminateTypeStore') == null) {
        Ext.create('Ext.data.Store', {
            storeId : 'illuminateVendorStore',
            fields : [ 'type','id','vendorId','socket','Eignung'],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });
        Ext.create('Ext.data.Store', {
            storeId : 'illuminateTypeStore',
            fields : [ 'id', 'vendor', 'passive' ],
            proxy : {
                type : 'memory',
                reader : {
                    type : 'json',
                    root : 'items'
                }
            }
        });
        var sString = dss.ajaxSyncRequest('/json/property/query', {
            'query' : '/scripts/led-wizard/entries(*)'
        });
        var result = Ext.JSON.decode(sString);
        if (result.ok) {
            var data=[];
            var vendorArray=[];
            for (var sKey in result.result.entries[0]) {
                var obj=Ext.JSON.decode(result.result.entries[0][sKey]);
                obj.id=sKey;
                data.push(obj);
                if (vendorArray.indexOf(obj.vendor)==-1)
                    vendorArray.push(obj.vendor);
                obj.vendorId=vendorArray.indexOf(obj.vendor);
            }
            Ext.data.StoreManager.lookup('illuminateTypeStore').add(data);
            for (var iIndex=0;iIndex<vendorArray.length;iIndex++)
                Ext.data.StoreManager.lookup('illuminateVendorStore').add({id:iIndex,vendor:vendorArray[iIndex]});
        }
    }
    
    var ledwizard = Ext.create('DSS.addon.Lizard');
    ledwizard.initPage();
});

